| Title: | Geocomputation with R Metapackage |
|---|---|
| Description: | Package supporting the book Geocomputation with R (\url{https://r.geocompx.org}). The packages in the Imports are required to build the first chapter of the book. The packages in Suggests are required for Part II and III. |
| Authors: | Robin Lovelace [aut], Jakub Nowosad [aut, cre], Jannes Muenchow [aut] |
| Maintainer: | Jakub Nowosad <[email protected]> |
| License: | CC BY-NC-ND 4.0 |
| Version: | 2.2.4 |
| Built: | 2026-05-28 07:27:48 UTC |
| Source: | https://github.com/geocompx/geocompkg |
Return details of issues, with input an GitHub issue URL
add_impact( url_issue, vars = c("created_at", "type", "title", "comments", "state", "creator"), url_old_impact = NULL )add_impact( url_issue, vars = c("created_at", "type", "title", "comments", "state", "creator"), url_old_impact = NULL )
url_issue |
The url of the issue to add |
vars |
Which variables to use? |
url_old_impact |
The previous state of the 'impact.csv' file |
## Not run: url_issue = "https://github.com/mtennekes/tmap/issues/196" geocompr:::add_impact(url_issue) u = "https://github.com/Robinlovelace/geocompr/raw/main/our-impact.csv" geocompr:::add_impact(url_issue, url_old_impact = u) ## End(Not run)## Not run: url_issue = "https://github.com/mtennekes/tmap/issues/196" geocompr:::add_impact(url_issue) u = "https://github.com/Robinlovelace/geocompr/raw/main/our-impact.csv" geocompr:::add_impact(url_issue, url_old_impact = u) ## End(Not run)